@@ -20,45 +20,6 @@ JS <- function (...)
 }
 
 
-#' Read a link-node structured JSON file into R as two data frames.
-#'
-#' \code{JSONtoDF} reads a JSON data file into R and converts part of it to a
-#' data frame.
-#'
-#' @param jsonStr a JSON object to convert. Note if \code{jsonStr} is specified,
-#' then \code{file} must be \code{NULL}.
-#' @param file character string of the JSON file name. Note if \code{file} is
-#' specified, then \code{jsonStr} must be \code{NULL}.
-#' @param array character string specifying the name of the JSON array to
-#' extract. (JSON arrays are delimited by square brackets).
-#'
-#' @details \code{JSONtoDF} is intended to load JSON files into R and convert
-#' them to data frames that can be used to create network graphs. The command
-#' converts the files into R lists and then extracts the JSON array the user
-#' would like to make into a data frame.
-#'
-#' @source Part of the idea for the command comes from mropa's comment on
-#' StackExchange:
-#' \url{http://stackoverflow.com/questions/4227223/r-list-to-data-frame}.
-#'
-#' @importFrom rjson fromJSON
-#' @importFrom plyr ldply
-#' @export
-
-JSONtoDF <- function(jsonStr = NULL, file = NULL, array){
-  if (!is.null(jsonStr) & !is.null(file)){
-    stop("Must specify jsonStr OR file.")
-  }
-  if (is.null(file)){
-    MainList <- fromJSON(json_str = jsonStr)
-  }
-  if (is.null(jsonStr)){
-    MainList <- fromJSON(file = file)
-  }
-  ArrayList <- MainList[[array]]
-  MainDF <- ldply(ArrayList, data.frame)
-  return(MainDF)
-}
 
 #' Internal function from Wei Luo to convert a data frame to a JSON array
 #'
@@ -98,3 +59,42 @@ toJSONarray <- function(dtf){
 read_file <- function(doc, ...){
   paste(readLines(doc, ...), collapse = '\n')
 }
+
+
+#' Utility function to handle margins
+#' @param margin an \code{integer}, a named \code{vector} of integers,
+#'    or a named \code{list} of integers specifying the margins
+#'    (top, right, bottom, and left)
+#'    in \code{px}/\code{pixels} for our htmlwidget.  If only a single
+#'    \code{integer} is provided, then the value will be assumed to be 
+#'    the \code{right} margin.
+#' @return named \code{list} with top, right, bottom, left margins
+#' @noRd
+margin_handler <- function(margin){
+  # margin can be either a single value or a list with any of
+  #    top, right, bottom, left
+  # if margin is a single value, then we will stick
+  #    with the original behavior of networkD3 and use it for the right margin
+  if(!is.null(margin) && length(margin) == 1 && is.null(names(margin))){
+    margin <- list(
+      top = NULL,
+      right = margin,
+      bottom = NULL,
+      left = NULL
+    )
+  } else if(!is.null(margin)){
+    # if margin is a named vector then convert to list
+    if(!is.list(margin) && !is.null(names(margin))){
+      margin <- as.list(margin)
+    }
+    # if we are here then margin should be a list and
+    #   we will use the values supplied with NULL as default
+    margin <- modifyList(
+      list(top = NULL, right = NULL, bottom = NULL, left = NULL),
+      margin
+    )
+  } else {
+    # if margin is null, then make it a list of nulls for each position
+    margin <- list(top = NULL, right = NULL, bottom = NULL, left = NULL)
+  } 
+}
\ No newline at end of file
