@@ -15,7 +15,7 @@ shinyUI(fluidPage(
         tabPanel("Force Network", forceNetworkOutput("force")),
         tabPanel("Force Network with Legend & Radius", forceNetworkOutput("forceRadius")),
         tabPanel("Sankey Network", sankeyNetworkOutput("sankey")),
-        tabPanel("Reingold-Tilford Tree", treeNetworkOutput("rt"))
+        tabPanel("Reingold-Tilford Tree", radialNetworkOutput("rt"))
       )
     )
   )
